function b=spdurb(Aavect)
% b=spdurb(Aavect)
% Uses Durbin's algorithm to solve Ab=c matrix equation.
% Aavect=augmented version of Avect, with a(1)=maximum
% element. A is (L+1)x(L+1) and c is [Aavect(2:L+2)].
% Inputs:
%  Aavect = 1st row of symmetric Toeplitz matrix, a0
%           thru aL, plus the additional element a(L+1).
%           Should be well conditioned with Aavect(1)=max.
%           See equation (11.32) for the form of Ab=c.
% Outputs:  
%    b   = solution vector, b in eq. (11.32); 1x(L+1).

L=length(Aavect)-2;
if L<0,
   error('SPLEVS: Length of Aavect is too short (< 2).');
end
epsilon=1e-10;
if abs(Aavect(1))<epsilon,
   epsilon
   error('SPDURB: Aavect(1) is less than epsilon.');
end
b=zeros(1,L+1);
b(1)=-Aavect(2)/Aavect(1);
s0=-b(1)*Aavect(2);
if L==0,
   b=-b;
   return
end
for nn=1:L,
   gamma=0;
   gammap=0;
   for i=1:nn,
      gamma=gamma-Aavect(i+1)*b(nn-i+1);
      gammap=gammap-Aavect(i+1)*b(i);
   end
   scl=Aavect(1)-gammap;
   if abs(scl/Aavect(1))<(eps*1e5),
      error('SPDURB: Singular condition encountered.');
   end
   beta=-(Aavect(nn+2)-gamma)/scl;
   for i=0:fix((nn-2)/2),
      tmp=b(i+1);
      b(i+1)=b(i+1)+beta*b(nn-i);
      if nn>1,
         b(nn-i)=b(nn-i)+beta*tmp;
      end
   end
   if fix((nn-2)/2)~=fix((nn-1)/2),
      b(fix((nn-1)/2)+1)=(1+beta)*b(fix((nn-1)/2)+1);
   end
   b(nn+1)=beta;
   s=-b(1)*Aavect(2);
   for i=1:nn,
      s=s-b(i+1)*Aavect(i+2);
   end   
   if (s0<=eps)&(s<=eps),
      error('SPDURB: Singular condition encountered.');
   elseif (s0>eps),
      if((s-s0)/s0<eps*1e6),
         error('SPDURB: Singular condition encountered.');
      end
   end
   s0=s;
end
b=-b;
return
