function h=spgain(b,a,freq)
% h=spgain(b,a,freq)
% Computes h = complex gain of any causal linear system.
% b,a = coefficient vectors in H(z)=B(z)/A(z); freq = Hz-s.
% (freq=scalar or row vector.)  See Chapter 5, section 5.3.
%           
% Transfer function coefficients are in arrays b and a such that:
%
%                      b(1)+b(2)*Z^(-1)+...+b(N)*Z^(-(N-1))
%               H(Z) = --------------------------------------
%                      a(1)+a(2)*Z^(-1)+...+a(M)*Z^(-(M-1)))
%
% where N=length(b) and M=length(a).  Usually, a(1)=1.
%
% For an FIR system with only B(z), use a=1, a scalar.
% For a parallel system, do each section and add the results.
% For a cascade system, do each section and multiply the results.
%
% Inputs:
%    b      = B(z) coefficient vector.
%    a      = A(z) coefficient vector.
%    freq   = Frequency in Hz-sec; i.e., sampling frequency = 1.0.
%             Note: freq can be a scalar or a row vector.
% Outputs:  
%    h      = Complex gain of H(Z) at frequency = freq Hz-s.

h=zeros(1,length(freq));
for m=1:length(freq),
   zz=exp(-j*2*pi*freq(m));
   bsum=b(1);
   if(length(b) > 1),
      bsum=bsum + sum(b(2:length(b)) .* (zz .^ [1:length(b)-1]));
   end
   asum=a(1);
   if(length(a) > 1),
      asum=asum + sum(a(2:length(a)) .* zz .^ [1:length(a)-1]);
   end
   h(m)=bsum/asum;
end
return
