function [b,a]=spiird(ifilt,iband,Ns,f1,f2,f3,f4,dB)
% [b,a]=spiird(ifilt,iband,Ns,f1,f2,f3,f4,dB)
% IIR lowpass, highpass, bandpass, and bandstop design of
% Chebyshev I, Chebyshev II, and Butterworth digital filters
% in cascade form.  See Chapter 7, Section 7.6.
% Inputs:
%    ifilt  = 1  Chebyshev I  (with passband ripple).
%             2  Chebyshev II (with stopband ripple).
%             3  Butterworth  (with no ripple).
%    iband  = 1  Lowpass.      3  Bandpass.
%             2  Highpass.     4  Bandstop.
%    Ns     = Number of sections in cascade.
%    f1-f4  = Frequency if Hz-sec (sampling frequency is 1.0):
%
%          f  f         f  f           f f  f f        f f f f
%          1  2         1  2           1 2  3 4        1 2 3 4
%    0 xxx-------   0 +------xxx   0 +----xx----   0 +x-------x
%      | x .  .       | .  . x       | . .xx. .      |x. . . .x
%      |  x.  .       | .  .x        | . .xx. .      |x. . . .x
%      |...x  .       |....x         |...x  x .      |.x.....x
%      |    x .       | . x          | . x  x .      |  x. .x
%      |     x.       | .x           | .x    x.      |  x. .x
%   dB |......x    dB |.x         dB |.x      x   dB |...xxx
%      |       x      |x             |x        x     |
%      
%             f3 & f4 are not used with any low or highpass.
%             f2 is not used with lowpass Butterworth.
%             f1 is not used with highpass Butterworth.
%             f1 & f4 are not used with bandpass Butterworth.
%             f2 & f3 are not used with bandstop Butterworth.
%
%    dB   = Stopband rejection (in dB; must be greater than 3 dB).
%                Applies to Chebyshev filters only;
%                not used with Butterworth filters.
% Outputs:  
%    b      = Numerator coefficients in each section (Ns rows).
%    a      = Denominator coefficients in each section (Ns rows).

if (Ns<=0)|(ifilt<1)|(ifilt>3)|(iband<1)|(iband>4)
   error('SPIIRD: Ns, ifilt or iband are out of range.');
end
if (iband==1)|(iband==4)
   fl=f1;
end
if (iband==2)|(iband==3)
   fl=f2;
end
if iband<=3
   fh=f3;
end
if iband==4
   fh=f4;
end
if iband<3
   if ((ifilt<3)&((f1<=0)|(f1>=f2)|(f2>=0.5)))|...
      ((ifilt==3)&((fl<=0)|(fl>=0.5)))
      error('SPIIRD: f1-f4 not in sequence or in (0,0.5).');
   end
elseif ifilt<3
   if (f1<=0)|(f1>=f2)|(f2>=f3)|(f3>=f4)|(f4>=0.5)
      error('SPIIRD: f1-f4 not in sequence or in (0,0.5).');
   end
elseif ifilt==3
   if (f1<=0)|(fl>=fh)|(fh>=0.5)
      error('SPIIRD: f1-f4 not in sequence or in (0,0.5).');
   end
end
if (ifilt<3)&(dB<=3)
      error('SPIIRD: attenuation in dB must be > 3.0.');
end
om1=tan(pi*f1); om4=tan(pi*f4);
om2=tan(pi*f2); om3=tan(pi*f3);
omh=tan(pi*fh); oml=tan(pi*fl);
if ifilt<3
   if iband<=2
      omega=tan(pi*f2)/tan(pi*f1);
   elseif iband==3
      om1sub=(om1^2-omh*oml)/((omh-oml)*om1);
      om4sub=(om4^2-omh*oml)/((omh-oml)*om4);
      omega=min(abs(om1sub),abs(om4sub));
   elseif iband==4
      om2sub=(om2^2-omh*oml)/((omh-oml)*om2);
      om3sub=(om3^2-omh*oml)/((omh-oml)*om3);
      omega=min(abs(1/om2sub),abs(1/om3sub));
   end
   alamda=10^(dB/20);
   epslon=alamda/cosh(2*Ns*acosh(omega));
end
for k=1:Ns,
   if ifilt==1
      [d,c]=spchbi(2*Ns,k,epslon);
   elseif ifilt==2
      [d,c]=spcbii(2*Ns,k,omega,alamda);
   elseif ifilt==3
      [d,c]=spbwcf(2*Ns,k);
   end
   [b(k,:),a(k,:)]=spfblt(d,c,iband,fl,fh);
end
return
