function b=splevs(Avect,c)
% b=splevs(Avect,c)
% Uses Levinson's algorithm to solve Ab=c matrix equation.
% Avect=1st row of Toeplitz matrix A, with a(1)=maximum
% element. A is (L+1)x(L+1) and c is (L+1)x1. See (11.26).
% Inputs:
%  Avect = 1st row of symmetric Toeplitz matrix A, which
%          should be well-conditioned with Avect(1)=max.
%          Avect has L+1 elements as in eq. (11.26).
%    c   = vector input; 1x(L+1).
% Outputs:  
%    b   = solution vector; 1x(L+1).

L=length(Avect)-1;
epsilon=1e-10;
if abs(Avect(1))<epsilon,
   epsilon
   error('SPLEVS: Avect(1) is less than epsilon.');
end
wk=zeros(1,L+1); b=zeros(1,L+1);
b(1)=c(1)/Avect(1);
s0=b(1)*c(1);
if L==0,
   return
end
v=1;
for m=0:L-1,
   u=Avect(m+2)/Avect(1);
   w=(c(m+2)-b(1)*Avect(m+2))/Avect(1);
   if m>0,
      for k=1:m,
         u=u-wk(m-k+1)*Avect(k+1)/Avect(1);
         w=w-b(k+1)*Avect(m+2-k)/Avect(1);
      end
   end
   wk(m+1)=u/v;
   if m>0,
      for n=0:fix((m-1)/2),
         temp=wk(n+1);
         wk(n+1)=temp-wk(m+1)*wk(m-n);
         if (m-n-1)~=n,
            wk(m-n)=wk(m-n)-wk(m+1)*temp;
         end
      end
   end
   v=v-wk(m+1)*u;
   if abs(v)<(epsilon*1e5),
      error('SPLEVS: Singular condition encountered.');
   end
   b(m+2)=w/v;
   s=b(m+2)*c(m+2);
   for k=0:m,
      b(k+1)=b(k+1)-wk(m-k+1)*b(m+2);
      s=s+b(k+1)*c(k+1);
   end
   if (s0<=epsilon)&(s<=epsilon),
      error('SPLEVS: Singular condition encountered.');
   elseif (s0>epsilon),
      if((s-s0)/s0<epsilon*1e6),
         error('SPLEVS: Singular condition encountered.');
      end
   end
   s0=s;
end
return
